summaryrefslogtreecommitdiffstats
path: root/src/mesa/state_tracker/st_texture.h
diff options
context:
space:
mode:
authorBrian Paul <[email protected]>2011-10-04 18:26:39 -0600
committerBrian Paul <[email protected]>2011-10-05 21:06:48 -0600
commitaff65241c8bf6206c6dfcbe774b87991f965d46f (patch)
treee9d643bc265b90bff3964161b0f568f5dcd4a5ac /src/mesa/state_tracker/st_texture.h
parent85f5aa156562168d2ecea140b4e087655b11d271 (diff)
st/mesa: completely stop using gl_texture_image::Data
Instead, use the new st_texture_image::TexData field to hold texture images that don't fit the parent object's mipmap buffer.
Diffstat (limited to 'src/mesa/state_tracker/st_texture.h')
-rw-r--r--src/mesa/state_tracker/st_texture.h7
1 files changed, 6 insertions, 1 deletions
diff --git a/src/mesa/state_tracker/st_texture.h b/src/mesa/state_tracker/st_texture.h
index dd3bc73100d..3d2a6369cfb 100644
--- a/src/mesa/state_tracker/st_texture.h
+++ b/src/mesa/state_tracker/st_texture.h
@@ -45,8 +45,13 @@ struct st_texture_image
{
struct gl_texture_image base;
+ /** Used to store texture data that doesn't fit in the patent
+ * object's mipmap buffer.
+ */
+ GLubyte *TexData;
+
/* If stImage->pt != NULL, image data is stored here.
* Else if stImage->base.Data != NULL, image is stored there.
* Else there is no image data.
*/
struct pipe_resource *pt;
@@ -45,8 +45,13 @@ struct st_texture_image
/* If stImage->pt != NULL, image data is stored here.
- * Else if stImage->base.Data != NULL, image is stored there.
+ * Else if stImage->TexData != NULL, image is stored there.
* Else there is no image data.
*/